pub trait TableKind: Clone {
// Required methods
fn table_name(&self) -> Cow<'_, str>;
fn table_key_label(&self) -> Cow<'_, str>;
fn table_key_column_width(&self) -> Option<f64>;
}Required Methods
fn table_name(&self) -> Cow<'_, str>
Sourcefn table_key_label(&self) -> Cow<'_, str>
fn table_key_label(&self) -> Cow<'_, str>
The column title for the key field in the rows
Sourcefn table_key_column_width(&self) -> Option<f64>
fn table_key_column_width(&self) -> Option<f64>
Width of key column in number of characters (as per Excel), None == automatic.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.